[Libreoffice-commits] .: configure.in set_soenv.in solenv/bin

Andras Timar timar at kemper.freedesktop.org
Thu Sep 1 00:48:29 PDT 2011


 configure.in                            |  181 ++++++++++++++++++++++++++++++++
 set_soenv.in                            |    9 +
 solenv/bin/make_installer.pl            |    2 
 solenv/bin/modules/installer/ziplist.pm |    8 +
 4 files changed, 197 insertions(+), 3 deletions(-)

New commits:
commit ae4ad0eabe36c4df524c99ae4dc509c0bd36c0c6
Author: Andras Timar <atimar at suse.com>
Date:   Thu Sep 1 09:39:11 2011 +0200

    extend branding options in configure

diff --git a/configure.in b/configure.in
index b2500b2..5ca79a5 100755
--- a/configure.in
+++ b/configure.in
@@ -1220,6 +1220,10 @@ AC_ARG_WITH(lang,
     ],
 ,)
 
+dnl ===================================================================
+dnl Branding
+dnl ===================================================================
+
 AC_ARG_WITH(intro-bitmap,
 [  --with-intro-bitmap    Prefer the specified intro bitmap over the
                           the default one.
@@ -1227,6 +1231,34 @@ AC_ARG_WITH(intro-bitmap,
                           Usage:     --with-intro-bitmap=/path/my_ooo_intro.png
 ],,)
 
+AC_ARG_WITH(intro-progressbar-color,
+[  --with-intro-progressbar-color    Set color of progress bar on intro screen.
+                                     Comma separated RGB values in decimal format.
+
+                          Usage: --with-intro-progressbar-color=126,170,23
+],,)
+
+AC_ARG_WITH(intro-progressbar-size,
+[  --with-intro-progressbar-size     Set size of progress bar on intro screen.
+                                     Comma separated values in decimal format.
+
+                          Usage: --with-intro-progressbar-size=319,10
+],,)
+
+AC_ARG_WITH(intro-progressbar-position,
+[  --with-intro-progressbar-position Set position of progress bar on intro screen.
+                                     Comma separated values in decimal format.
+
+                          Usage: --with-intro-progressbar-position=164,225
+],,)
+
+AC_ARG_WITH(intro-progressbar-frame-color,
+[  --with-intro-progressbar-frame-color    Set color of progress bar frame on intro screen.
+                                           Comma separated RGB values in decimal format.
+
+                          Usage: --with-intro-progressbar-frame-color=207,208,211
+],,)
+
 AC_ARG_WITH(about-bitmap,
 [  --with-about-bitmap    Similarly to --with-intro-bitmap, this allows
                           specification of bitmap for the About box.
@@ -1234,6 +1266,41 @@ AC_ARG_WITH(about-bitmap,
                           Usage:     --with-about-bitmap=/path/my_ooo_about.png
 ],,)
 
+AC_ARG_WITH(startcenter-left-bitmap,
+[  --with-startcenter-left-bitmap    Similarly to --with-intro-bitmap, this allows
+                                     specification of bitmap for the Start center.
+
+                          Usage: --with-startcenter-left-bitmap=/path/my_backing_left.png
+],,)
+
+AC_ARG_WITH(startcenter-right-bitmap,
+[  --with-startcenter-right-bitmap    Similarly to --with-intro-bitmap, this allows
+                                      specification of bitmap for the Start center.
+
+                          Usage: --with-startcenter-right-bitmap=/path/my_backing_right.png
+],,)
+
+AC_ARG_WITH(startcenter-rtl-left-bitmap,
+[  --with-startcenter-rtl-left-bitmap    Similarly to --with-intro-bitmap, this allows
+                                         specification of bitmap for the Start center.
+
+                          Usage: --with-startcenter-rtl-left-bitmap=/path/my_backing_rtl_left.png
+],,)
+
+AC_ARG_WITH(startcenter-rtl-right-bitmap,
+[  --with-startcenter-rtl-right-bitmap    Similarly to --with-intro-bitmap, this allows
+                                          specification of bitmap for the Start center.
+
+                          Usage: --with-startcenter-rtl-right-bitmap=/path/my_backing_rtl_right.png
+],,)
+
+AC_ARG_WITH(startcenter-space-bitmap,
+[  --with-startcenter-space-bitmap    Similarly to --with-intro-bitmap, this allows
+                                      specification of bitmap for the Start center.
+
+                          Usage: --with-startcenter-space-bitmap=/path/my_backing_space.png
+],,)
+
 AC_ARG_WITH(vendor,
     AS_HELP_STRING([--with-vendor],
         [Set vendor of the build.])
@@ -8878,6 +8945,50 @@ else
 fi
 AC_SUBST(INTRO_BITMAP)
 
+AC_MSG_CHECKING([for custom 'intro' progress bar color])
+PROGRESSBARCOLOR=
+if test -z "$with_intro_progressbar_color" ; then
+   PROGRESSBARCOLOR="126,170,23"
+   AC_MSG_RESULT([none])
+else
+   PROGRESSBARCOLOR="$with_intro_progressbar_color"
+   AC_MSG_RESULT([$PROGRESSBARCOLOR])
+fi
+AC_SUBST(PROGRESSBARCOLOR)
+
+AC_MSG_CHECKING([for custom 'intro' progress bar size])
+PROGRESSSIZE=
+if test -z "$with_intro_progressbar_size" ; then
+   PROGRESSSIZE="319,10"
+   AC_MSG_RESULT([none])
+else
+   PROGRESSSIZE="$with_intro_progressbar_size"
+   AC_MSG_RESULT([$PROGRESSSIZE])
+fi
+AC_SUBST(PROGRESSSIZE)
+
+AC_MSG_CHECKING([for custom 'intro' progress bar position])
+PROGRESSPOSITION=
+if test -z "$with_intro_progressbar_position" ; then
+   PROGRESSPOSITION="164,225"
+   AC_MSG_RESULT([none])
+else
+   PROGRESSPOSITION="$with_intro_progressbar_position"
+   AC_MSG_RESULT([$PROGRESSPOSITION])
+fi
+AC_SUBST(PROGRESSPOSITION)
+
+AC_MSG_CHECKING([for custom 'intro' progress bar frame color])
+PROGRESSFRAMECOLOR=
+if test -z "$with_intro_progressbar_frame_color" ; then
+   PROGRESSFRAMECOLOR="207,208,211"
+   AC_MSG_RESULT([none])
+else
+   PROGRESSFRAMECOLOR="$with_intro_progressbar_frame_color"
+   AC_MSG_RESULT([$PROGRESSFRAMECOLOR])
+fi
+AC_SUBST(PROGRESSFRAMECOLOR)
+
 AC_MSG_CHECKING([for another 'about' bitmap])
 ABOUT_BITMAP=
 if test -z "$with_about_bitmap" -o "$with_about_bitmap" = "no" ; then
@@ -8892,6 +9003,76 @@ else
 fi
 AC_SUBST(ABOUT_BITMAP)
 
+AC_MSG_CHECKING([for another 'start center left' bitmap])
+STARTCENTER_LEFT_BITMAP=
+if test -z "$with_startcenter_left_bitmap" -o "$with_startcenter_left_bitmap" = "no" ; then
+   STARTCENTER_LEFT_BITMAP=
+   AC_MSG_RESULT([none])
+else
+   case "$with_startcenter_left_bitmap" in
+      *.png) STARTCENTER_LEFT_BITMAP="$with_startcenter_left_bitmap" ;;
+      *)     AC_MSG_WARN([Startcenter left bitmap should be a .png file!]) ;;
+   esac
+   AC_MSG_RESULT([$STARTCENTER_LEFT_BITMAP])
+fi
+AC_SUBST(STARTCENTER_LEFT_BITMAP)
+
+AC_MSG_CHECKING([for another 'start center right' bitmap])
+STARTCENTER_RIGHT_BITMAP=
+if test -z "$with_startcenter_right_bitmap" -o "$with_startcenter_right_bitmap" = "no" ; then
+   STARTCENTER_RIGHT_BITMAP=
+   AC_MSG_RESULT([none])
+else
+   case "$with_startcenter_right_bitmap" in
+      *.png) STARTCENTER_RIGHT_BITMAP="$with_startcenter_right_bitmap" ;;
+      *)     AC_MSG_WARN([Startcenter right bitmap should be a .png file!]) ;;
+   esac
+   AC_MSG_RESULT([$STARTCENTER_RIGHT_BITMAP])
+fi
+AC_SUBST(STARTCENTER_RIGHT_BITMAP)
+
+AC_MSG_CHECKING([for another 'start center rtl left' bitmap])
+STARTCENTER_RTL_LEFT_BITMAP=
+if test -z "$with_startcenter_rtl_left_bitmap" -o "$with_startcenter_rtl_left_bitmap" = "no" ; then
+   STARTCENTER_RTL_LEFT_BITMAP=
+   AC_MSG_RESULT([none])
+else
+   case "$with_startcenter_rtl_left_bitmap" in
+      *.png) STARTCENTER_RTL_LEFT_BITMAP="$with_startcenter_rtl_left_bitmap" ;;
+      *)     AC_MSG_WARN([Startcenter rtl left bitmap should be a .png file!]) ;;
+   esac
+   AC_MSG_RESULT([$STARTCENTER_RTL_LEFT_BITMAP])
+fi
+AC_SUBST(STARTCENTER_RTL_LEFT_BITMAP)
+
+AC_MSG_CHECKING([for another 'start center rtl right' bitmap])
+STARTCENTER_RTL_RIGHT_BITMAP=
+if test -z "$with_startcenter_rtl_right_bitmap" -o "$with_startcenter_rtl_right_bitmap" = "no" ; then
+   STARTCENTER_RTL_RIGHT_BITMAP=
+   AC_MSG_RESULT([none])
+else
+   case "$with_startcenter_rtl_right_bitmap" in
+      *.png) STARTCENTER_RTL_RIGHT_BITMAP="$with_startcenter_rtl_right_bitmap" ;;
+      *)     AC_MSG_WARN([Startcenter rtl right bitmap should be a .png file!]) ;;
+   esac
+   AC_MSG_RESULT([$STARTCENTER_RTL_RIGHT_BITMAP])
+fi
+AC_SUBST(STARTCENTER_RTL_RIGHT_BITMAP)
+
+AC_MSG_CHECKING([for another 'start center space' bitmap])
+STARTCENTER_SPACE_BITMAP=
+if test -z "$with_startcenter_space_bitmap" -o "$with_startcenter_space_bitmap" = "no" ; then
+   STARTCENTER_SPACE_BITMAP=
+   AC_MSG_RESULT([none])
+else
+   case "$with_startcenter_space_bitmap" in
+      *.png) STARTCENTER_SPACE_BITMAP="$with_startcenter_space_bitmap" ;;
+      *)     AC_MSG_WARN([Startcenter left bitmap should be a .png file!]) ;;
+   esac
+   AC_MSG_RESULT([$STARTCENTER_SPACE_BITMAP])
+fi
+AC_SUBST(STARTCENTER_SPACE_BITMAP)
+
 OOO_VENDOR=
 AC_MSG_CHECKING([for vendor])
 if test -z "$with_vendor" -o "$with_vendor" = "no" ; then
diff --git a/set_soenv.in b/set_soenv.in
index 5463c35..0717241 100755
--- a/set_soenv.in
+++ b/set_soenv.in
@@ -1436,7 +1436,16 @@ ToFile( "Platform independent constant values.", $empty, "c" );
 ToFile( "WITH_LANG",         "@WITH_LANG@",      "e" );
 ToFile( "WITH_LANG_LIST",    "@WITH_LANG_LIST@", "e" );
 ToFile( "INTRO_BITMAP",      "@INTRO_BITMAP@",   "e" );
+ToFile( "PROGRESSBARCOLOR",  "@PROGRESSBARCOLOR@",   "e" );
+ToFile( "PROGRESSSIZE",      "@PROGRESSSIZE@",       "e" );
+ToFile( "PROGRESSPOSITION",  "@PROGRESSPOSITION@",   "e" );
+ToFile( "PROGRESSFRAMECOLOR","@PROGRESSFRAMECOLOR@", "e" );
 ToFile( "ABOUT_BITMAP",      "@ABOUT_BITMAP@",   "e" );
+ToFile( "STARTCENTER_LEFT_BITMAP",      "@STARTCENTER_LEFT_BITMAP@",      "e" );
+ToFile( "STARTCENTER_RIGHT_BITMAP",     "@STARTCENTER_RIGHT_BITMAP@",     "e" );
+ToFile( "STARTCENTER_RTL_LEFT_BITMAP",  "@STARTCENTER_RTL_LEFT_BITMAP@",  "e" );
+ToFile( "STARTCENTER_RTL_RIGHT_BITMAP", "@STARTCENTER_RTL_RIGHT_BITMAP@", "e" );
+ToFile( "STARTCENTER_SPACE_BITMAP",     "@STARTCENTER_SPACE_BITMAP@",     "e" );
 ToFile( "OOO_VENDOR",        "@OOO_VENDOR@",     "e" );
 ToFile( "OOODMAKEMODE",      "YES",              "e" );
 ToFile( "PRODUCTVERSION",    "@PRODUCTVERSION@", "e" );
diff --git a/solenv/bin/make_installer.pl b/solenv/bin/make_installer.pl
index c8e92dc..e8c2a74 100644
--- a/solenv/bin/make_installer.pl
+++ b/solenv/bin/make_installer.pl
@@ -254,7 +254,7 @@ if ( $installer::globals::globallogging ) { installer::files::save_hash($logging
 installer::ziplist::add_variables_to_allvariableshashref($allvariableshashref);
 if ( $installer::globals::globallogging ) { installer::files::save_hash($loggingdir . "allvariables3b.log", $allvariableshashref); }
 
-installer::ziplist::overwrite_ooovendor( $allvariableshashref );
+installer::ziplist::overwrite_branding( $allvariableshashref );
 if ( $installer::globals::globallogging ) { installer::files::save_hash($loggingdir . "allvariables3c.log", $allvariableshashref); }
 
 
diff --git a/solenv/bin/modules/installer/ziplist.pm b/solenv/bin/modules/installer/ziplist.pm
index f0ea1ac..dc8aeff 100644
--- a/solenv/bin/modules/installer/ziplist.pm
+++ b/solenv/bin/modules/installer/ziplist.pm
@@ -749,13 +749,17 @@ sub replace_variables_in_ziplist_variables
 }
 
 ###########################################################
 # Overwrite the vendor string in openoffice.lst that is defined in configure
 ###########################################################
 
-sub overwrite_ooovendor
+sub overwrite_branding
 {
     my ($variableshashref) = @_;
     $variableshashref->{'OOOVENDOR'} = $ENV{'OOO_VENDOR'} , if( defined $ENV{'OOO_VENDOR'}  && $ENV{'OOO_VENDOR'} ne "" );
+    $variableshashref->{'PROGRESSBARCOLOR'} = $ENV{'PROGRESSBARCOLOR'} , if( defined $ENV{'PROGRESSBARCOLOR'}  && $ENV{'PROGRESSBARCOLOR'} ne "" );
+    $variableshashref->{'PROGRESSSIZE'} = $ENV{'PROGRESSSIZE'} , if( defined $ENV{'PROGRESSSIZE'}  && $ENV{'PROGRESSSIZE'} ne "" );
+    $variableshashref->{'PROGRESSPOSITION'} = $ENV{'PROGRESSPOSITION'} , if( defined $ENV{'PROGRESSPOSITION'}  && $ENV{'PROGRESSPOSITION'} ne "" );
+    $variableshashref->{'PROGRESSFRAMECOLOR'} = $ENV{'PROGRESSFRAMECOLOR'} , if( defined $ENV{'PROGRESSFRAMECOLOR'}  && $ENV{'PROGRESSFRAMECOLOR'} ne "" );
 }
 
 ###########################################################
@@ -749,13 +749,17 @@ sub replace_variables_in_ziplist_variables
 
 ###########################################################
-# Overwrite the vendor string in openoffice.lst that is defined in configure
+# Overwrite branding data in openoffice.lst that is defined in configure
 ###########################################################
 


More information about the Libreoffice-commits mailing list